AAR: Attribute-wise agreement rate

View source: R/AAR.R

AARR Documentation

Attribute-wise agreement rate

Description

The function is used to compute the attribute-wise agreement rate between two sets of attribute profiles. They need to have the same dimensions.

Usage

AAR(x, y)

Arguments

x

One set of attribute profiles

y

The other set of attribute profiles

Value

The function returns the attribute-wise agreement rate between two sets of attribute profiles.

See Also

PAR

Examples

# see examples used for GNPC.


NPCDTools documentation built on Sept. 1, 2026, 1:08 a.m.

Related to AAR in NPCDTools...