MCNPC: The Nonparametric Classification Method for Multiple-Choice...

View source: R/MCNPC.R

MCNPCR Documentation

The Nonparametric Classification Method for Multiple-Choice Items

Description

Function MCNPC is used to estimate examinees' attribute profiles using the general nonparametric classification method for multiple-choice items (MC-NPC). Different from the traditional multiple-choice items where distractors are not coded, Some or all of the distractors are coded and responses are polytomous. Studies have shown that such a format will increase the classification rates compared to the binary format.

Usage

MCNPC(dat, mcQ, H, LS = NULL)

Arguments

dat

A N \times J polytomous data matrix consisting of the responses from N examinees to J items.

mcQ

A \sum_{j=1}^J H_j \times (K+2) binary matrix where H_j is the number of coded options for item j. The first and second columns contain the IDs of the items and the IDs of the coded options. Columns 3 to K+2 contains the q-entries of the coded options. For each item, the first row is designated to the key and the others are to the coded distractors.

H

The number of options. By default, all items have the same number of options.

LS

A matrix representing the possible attribute patterns in the data. The default (= NULL) is the 2^K attribute patterns expanded by the K binary attributes. It can also take user-specified attribute patterns.

Value

The function returns

att

The estimated attribute patterns

classID

The estimated class memberships

distance order

The order of latent classes based on the corresponding distances

distance

The calculated distances associated with the possible latent classes

latentclass

The possible latent classes in the data


NPCDTools documentation built on Sept. 1, 2026, 1:08 a.m.

Related to MCNPC in NPCDTools...