PAR: Pattern-wise agreement rate

View source: R/PAR.R

PARR Documentation

Pattern-wise agreement rate

Description

The function is used to compute the pattern-wise agreement rate between two sets of attribute profiles. They need to have the same dimensions.

Usage

PAR(x, y)

Arguments

x

One set of attribute profiles

y

The other set of attribute profiles

Value

The function returns the pattern-wise agreement rate between two sets of attribute profiles.

See Also

AAR

Examples

# see examples used for GNPC.

NPCDTools documentation built on Sept. 1, 2026, 1:08 a.m.

Related to PAR in NPCDTools...