bestQperm: Column permutation of a Q-matrix with respect to a benchmark...

View source: R/bestQperm.R

bestQpermR Documentation

Column permutation of a Q-matrix with respect to a benchmark Q-matrix.

Description

Function bestQperm is used to permute the columns of a Q-matrix so that the order of the columns best matches that of the benchmark Q-matrix. This function is useful in a Q-matrix estimation process.

Usage

bestQperm(Q, bench.Q)

Arguments

Q

The targeted Q-matrix.

bench.Q

The benchmark Q-matrix.

Value

The function returns a Q-matrix in which the order of the columns best matches that of the benchmark Q-matrix.

Examples

# See examples used for TSQE.


NPCDTools documentation built on Sept. 1, 2026, 1:08 a.m.