correction.rate: Correction rate of a Q-matrix refinement method

View source: R/correction_rate.R

correction.rateR Documentation

Correction rate of a Q-matrix refinement method

Description

This function computes the proportion of corrected q-entries that were originally misspecified in the provisional Q-matrix. This function is used only when the true Q-matrix is known.

Usage

correction.rate(ref.Q = ref.Q, mis.Q = mis.Q, true.Q = true.Q)

Arguments

ref.Q

The J \times K refined binary Q-matrix.

mis.Q

A J \times K binary provisional Q-matrix.

true.Q

The J \times K binary true Q-matrix.

Value

The function returns a value between 0 and 1 representing the proportion of corrected q-entries in ref.Q that were originally misspecified in mis.Q.

Examples

# See examples used for QR function.

NPCDTools documentation built on Sept. 1, 2026, 1:08 a.m.