distractor.check: Detect the implausible and improper distractors in a Q-Matrix...

View source: R/distractor.check.R

distractor.checkR Documentation

Detect the implausible and improper distractors in a Q-Matrix for multiple-choice items

Description

Function distractor.check is used to assess whether the distractors of a given Q-matrix for multiple-choice items are plausible and/or proper.

Usage

distractor.check(mcQ, key = NULL)

Arguments

mcQ

The given Q-matrix for multiple-choice items. It has to be organized in the following manner. The Q-matrix should contain K+2 columns and \sum_{j=1}^J H_j rows, where H_j is the number of coded options for item j. Among the H_j rows for item j, the first row is the key, followed by the coded distractors. The first column of the Q-matrix lists the ID of the items and second column indicates the corresponding options of the coded options. If the Q-matrix is not organized in such a way, an argument key (see below) that indicates the options that the keys are located needs to be given.

key

A vector that indicates the options where the keys are located.

Value

A list with class "distractor.check" containing:

not.plausible

A matrix indicating items and options that are not plausible, or NULL if all items are plausible.

not.proper

A vector of item IDs that are not proper, or NULL if all items are proper.

all.plausible

Logical; TRUE if all items are plausible.

all.proper

Logical; TRUE if all items are proper.

References

Chiu, C.-Y., Köhn, H. F. & Wang, Y. (Online first). Plausible and proper multiple-choice items for diagnostic classification. Psychometrika.

Examples

## Not run: 
library(NPCDTools)
Q1 <- Q_Ozaki
distractor.check(Q1)

Q2 <- GDINA::sim10MCDINA2$simQ
key <- c(1, 2, 4, 1, 1, 3, 2, 4, 1, 4)
distractor.check(Q2, key)

## End(Not run)


NPCDTools documentation built on Sept. 1, 2026, 1:08 a.m.