| MCNPC | R Documentation |
Function MCNPC is used to estimate examinees' attribute profiles using the general nonparametric classification method for multiple-choice items (MC-NPC).
Different from the traditional multiple-choice items where distractors are not coded, Some or all of the distractors are coded and responses are polytomous.
Studies have shown that such a format will increase the classification rates compared to the binary format.
MCNPC(dat, mcQ, H, LS = NULL)
dat |
A |
mcQ |
A |
H |
The number of options. By default, all items have the same number of options. |
LS |
A matrix representing the possible attribute patterns in the data. The default (= NULL) is the |
The function returns
The estimated attribute patterns
The estimated class memberships
The order of latent classes based on the corresponding distances
The calculated distances associated with the possible latent classes
The possible latent classes in the data
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.