| NPC | R Documentation |
The function estimates examinees' attribute profiles using the nonparametric classification (NPC) method (Chiu & Douglas, 2013). An examinee's attribute profile is estimated by minimizing the distance between the observed and ideal item responses.
NPC(
Y,
Q,
distance = c("hamming", "whamming", "penalized"),
gate = c("AND", "OR"),
wg = 1,
ws = 1
)
Y |
A |
Q |
A |
distance |
The type of distance used to compute the loss function. The possible options include
(i) " |
gate |
A character string specifying the type of gate. The possible options include " |
wg |
Additional argument for the "penalized" method. It is a weight assigned to guesses in the DINA or DINO models. A large value of weight results in a stronger impact on the distance (i.e., larger loss function values) caused by guessing. |
ws |
Additional input for the "penalized" method. It is the weight assigned to slips in the DINA or DINO models. A large value of weight results in a stronger impact on the distance (i.e., larger loss function values) caused by slipping. |
The function returns a series of outputs, including:
A N \times K matrix representing the estimated attribute profiles.
1 = examinee masters the attribute, 0 = examinee does not master the attribute.
A N \times J matrix indicating the estimated ideal response to all
items from all examinees. 1 = correct, 0 = incorrect.
A N-dimensional vector showing the class memberships for all examinees.
The number of ties in the Hamming distance among the candidate attribute profiles for each person. When ties occur, one of the tied attribute profiles is randomly chosen.
All possible attribute profiles in the latent space.
A 2^K \times N matrix containing the values of the loss function
(the distances) between each examinee's observed response vector and the 2^K ideal response vectors.
The nonparametric classification (NPC) method (Chiu & Douglas, 2013) assigns examinees to the
proficiency classes they belong to by comparing their observed item response patterns with each of the ideal
item response patterns of the 2^K proficiency classes. When there is no data perturbation, an
examinee's ideal response pattern corresponding to the examinee's true attribute pattern and his/her
observed item response patterns are identical, and thus the distance between them is 0. When data
perturbations are small, this ideal response pattern remains the one most similar to the observed
response pattern, which is exactly the setup of data conforming to the DINA or DINO model. Hence, based
on this rationale, an examinee's attribute profile is obtained by minimizing the distance between the
observed and the ideal item response patterns. The nonparametric nature of the NPC method furthermore
makes it suitable for data obtained from small-scale settings.
Chiu, C. Y., & Douglas, J. A. (2013). A nonparametric approach to cognitive diagnosis by proximity to ideal response patterns. Journal of Classification, 30(2), 225-250. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1007/s00357-013-9132-9")}
GNPC
## Not run:
library(GDINA)
N <- 500
Q <- sim30GDINA$simQ
gs <- data.frame(guess = rep(0.2, nrow(Q)), slip = rep(0.2, nrow(Q)))
sim <- simGDINA(N, Q, gs.parm = gs, model = "DINA")
Y <- extract(sim, what = "dat")
alpha <- extract(sim, what = "attribute")
# Estimate attribute profiles using NPC
result <- NPC(Y, Q, distance = "hamming", gate = "AND")
print(result)
result$att.est
# Check attributed agreement rate
PAR(alpha, result$att.est)
AAR(alpha, result$att.est)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.