| bestQperm | R Documentation |
Function bestQperm is used to permute the columns of a Q-matrix so that
the order of the columns best matches that of the benchmark Q-matrix. This function
is useful in a Q-matrix estimation process.
bestQperm(Q, bench.Q)
Q |
The targeted Q-matrix. |
bench.Q |
The benchmark Q-matrix. |
The function returns a Q-matrix in which the order of the columns best matches that of the benchmark Q-matrix.
# See examples used for TSQE.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.