View source: R/distractor.check.R
| distractor.check | R Documentation |
Function distractor.check is used to assess whether the distractors of a given Q-matrix for multiple-choice items are plausible and/or proper.
distractor.check(mcQ, key = NULL)
mcQ |
The given Q-matrix for multiple-choice items. It has to be organized in the following manner. The Q-matrix should contain |
key |
A vector that indicates the options where the keys are located. |
A list with class "distractor.check" containing:
A matrix indicating items and options that are not plausible, or NULL if all items are plausible.
A vector of item IDs that are not proper, or NULL if all items are proper.
Logical; TRUE if all items are plausible.
Logical; TRUE if all items are proper.
Chiu, C.-Y., Köhn, H. F. & Wang, Y. (Online first). Plausible and proper multiple-choice items for diagnostic classification. Psychometrika.
## Not run:
library(NPCDTools)
Q1 <- Q_Ozaki
distractor.check(Q1)
Q2 <- GDINA::sim10MCDINA2$simQ
key <- c(1, 2, 4, 1, 1, 3, 2, 4, 1, 4)
distractor.check(Q2, key)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.