View source: R/mcdat.generate.R
| mcdat.generate | R Documentation |
This function generates MC responses conforming to the MC-DINA model with relaxed MC Q-matrix.
mcdat.generate(
mcQ,
N,
H,
att.structure = "unif",
cor.att = 0.5,
lambda = rep(0.85, J)
)
mcQ |
A |
N |
The number of examinees |
H |
The number of maximal attributes required by the items. H takes values 3, 4, 5, or 6. |
att.structure |
The structure of attribute profiles. Possible options are |
cor.att |
If |
lambda |
A |
The function returns
A N\times J matrix storing the generated responses
Examinees' attribute profiles (N\times K) used to generate the responses
A list storing the probabilities that the examinees are attracted by the options of the items
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.